@@ -98,7 +98,7 @@ SEXP get_splitctrl(SEXP object);
 SEXP get_gtctrl(SEXP object);
 double get_mincriterion(SEXP object);
 int get_randomsplits(SEXP object);
-int get_mtry(SEXP object);
+SEXP get_mtry(SEXP object);
 SEXP get_dontuse(SEXP object);
 SEXP get_dontusetmp(SEXP object);
 int get_stump(SEXP object);
